<div align="center">

# Ox[MPL](https://github.com/ompl/ompl)

The Open Motion-Planning Library but Oxidised

</div>
<div align="center">
<br>
</div>

OxMPL is a sampling-based motion planning library written in Rust, inspired by the structure and concepts of [OMPL](http://ompl.kavrakilab.org/).

It provides a flexible and type-safe Rust API for core planning algorithms and offers high-level Python and JavaScript/WASM bindings for rapid prototyping and integration.

## Documentation



Full documentation, including installation guides, quick-start examples, and API references for all supported languages, is available in the **[OxMPL Book](https://juniorsundar.github.io/oxmpl/)**.

### Local Documentation

To build and view the documentation locally:

```bash
cd docs
mdbook serve --open
```

## License

This project is licensed under the **BSD-3-Clause License**. See the [LICENSE](https://github.com/juniorsundar/oxmpl/blob/main/LICENSE) file for details.
